@@ -1,6 +1,6 @@
 package Geo::SypexGeo;
 
-our $VERSION = '0.6';
+our $VERSION = '0.7';
 
 use strict;
 use warnings;
@@ -129,7 +129,14 @@ sub get_country {
   my $info = $self->parse_info($seek);
   return unless $info;
 
-  my $country = $COUNTRY_ISO_MAP[ $info->[1] ];
+  my $country;
+  if ( $info->[1] =~ /\D/ ) {
+    $country = $info->[1];
+  }
+  else {
+    $country = $COUNTRY_ISO_MAP[ $info->[1] ];
+  }
+
   return $country;
 }
 
@@ -452,6 +459,7 @@ Andrey Kuzmin, E<lt>kak-tus@mail.ruE<gt>
 =head1 CREDITS
 
 vrag86
+dimonchik-com
 
 =head1 COPYRIGHT AND LICENSE
 
